@@ -1,6 +1,6 @@
 package Email::MIME::Kit::Assembler::Markdown;
 # ABSTRACT: build multipart/alternative messages from Markdown alone
-$Email::MIME::Kit::Assembler::Markdown::VERSION = '0.100004';
+$Email::MIME::Kit::Assembler::Markdown::VERSION = '0.100005';
 use Moose;
 with 'Email::MIME::Kit::Role::Assembler';
 
@@ -81,13 +81,17 @@ has text_wrapper => (
 
 has munge_signature => (
   is  => 'ro',
-  isa => 'Bool',
+  # XXX Removed because JSON booly objects (and YAML?) aren't consistently
+  # compatible with Moose's Bool type. -- rjbs, 2016-08-03
+  # isa => 'Bool',
   default => 0,
 );
 
 has render_wrapper => (
   is      => 'ro',
-  isa     => 'Bool',
+  # XXX Removed because JSON booly objects (and YAML?) aren't consistently
+  # compatible with Moose's Bool type. -- rjbs, 2016-08-03
+  # isa     => 'Bool',
   default => 0,
 );
 
@@ -250,7 +254,7 @@ Email::MIME::Kit::Assembler::Markdown - build multipart/alternative messages fro
 
 =head1 VERSION
 
-version 0.100004
+version 0.100005
 
 =head1 SYNOPSIS
 
